Struct MountedFatfs
Source pub struct MountedFatfs<T> { }
Represents a mounted FAT filesystem.
Mount a FAT filesystem.
Arguments
fatfs: The FAT filesystem instance to mount.
path: The path to mount the filesystem at.
max_fds: The maximum number of file descriptors to allocate.
SourceAvailable on crate feature alloc only.
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.